@@ -2,8 +2,9 @@ package DateTime::Types;
 
 use strict;
 use warnings;
+use namespace::autoclean;
 
-our $VERSION = '1.32';
+our $VERSION = '1.60';
 
 use parent 'Specio::Exporter';
 
@@ -81,7 +82,7 @@ my $time_zone_object = object_can_type(
             name
             offset_for_datetime
             short_name_for_datetime
-            )
+        )
     ],
 );
 
@@ -144,7 +145,7 @@ enum(
             nanosecond
             week
             local_week
-            )
+        )
     ],
 );
 
@@ -155,7 +156,7 @@ declare(
 
 1;
 
-# ABSTRACT: Types used for parameter checking DateTime
+# ABSTRACT: Types used for parameter checking in DateTime
 
 __END__
 
@@ -165,11 +166,11 @@ __END__
 
 =head1 NAME
 
-DateTime::Types - Types used for parameter checking DateTime
+DateTime::Types - Types used for parameter checking in DateTime
 
 =head1 VERSION
 
-version 1.37
+version 1.60
 
 =head1 DESCRIPTION
 
@@ -179,13 +180,14 @@ This module has no user-facing parts.
 
 =head1 SUPPORT
 
-Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=DateTime>
-(or L<bug-datetime@rt.cpan.org|mailto:bug-datetime@rt.cpan.org>).
+Bugs may be submitted at L<https://github.com/houseabsolute/DateTime.pm/issues>.
 
 There is a mailing list available for users of this distribution,
 L<mailto:datetime@perl.org>.
 
-I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+=head1 SOURCE
+
+The source code repository for DateTime can be found at L<https://github.com/houseabsolute/DateTime.pm>.
 
 =head1 AUTHOR
 
@@ -193,10 +195,13 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Dave Rolsky.
+This software is Copyright (c) 2003 - 2023 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
